@@ -11,6 +11,8 @@ import six
 
 from certbot import errors
 
+from certbot.tests import util as test_util
+
 
 class ReverterCheckpointLocalTest(unittest.TestCase):
     # pylint: disable=too-many-instance-attributes, too-many-public-methods
@@ -375,7 +377,7 @@ class TestFullCheckpointsReverter(unittest.TestCase):
         self.assertEqual(read_in(self.config2), "directive-dir2")
         self.assertFalse(os.path.isfile(config3))
 
-    @mock.patch("certbot.reverter.zope.component.getUtility")
+    @test_util.patch_get_utility()
     def test_view_config_changes(self, mock_output):
         """This is not strict as this is subject to change."""
         self._setup_three_checkpoints()
